@@ -12,7 +12,7 @@ use Image::Size;
 require Exporter;
 use vars '$VERSION';
 
-$VERSION = '2.15';
+$VERSION = '2.16';
 
 =head1 NAME
 
@@ -20,7 +20,7 @@ CGI::Uploader - Manage CGI uploads using SQL database
 
 =head1 Synopsis
 
- use CGI::Uploader::Transform::ImageMagick (qw/gen_thumb/);
+ use CGI::Uploader::Transform::ImageMagick 'gen_thumb';
 
  my $u = CGI::Uploader->new(
  	spec       => {
@@ -647,11 +647,7 @@ sub upload {
 
    my ($tmp_fh, $tmp_filename) = tempfile('CGIuploaderXXXXX', UNLINK => 1, DIR => $self->{'temp_dir'} );
 
-   #   Determine whether binary mode is required in the handling of uploaded 
-   #   files - 
-   #   Binary mode is deemed to be required when we (the server) are running one one 
-   #   of these platforms: for Windows, OS/2 and VMS 
-   binmode($tmp_fh) if ($^O =~ /OS2|VMS|Win|DOS|Cygwin/i);
+   binmode($fh);
 
    require File::Copy;
    import  File::Copy;
@@ -707,7 +703,7 @@ sub store_upload {
     # Transform file if needed
     if (my $meth = $self->{spec}{$file_field}{transform_method}) {
         $tmp_filename = $meth->( $self, 
-            $file_name,
+            $tmp_filename,
             $self->{spec}{$file_field}{params},
         );
     }
@@ -1040,7 +1036,7 @@ sub store_meta {
 
     if (!$is_update && $self->{db_driver} eq 'Pg') {
         $id = $DBH->selectrow_array("SELECT NEXTVAL('".$self->{up_seq}."')");
-        $copy{upload_id} = $id;
+	$copy{$map->{upload_id} } = $id;
     }
 
     my @orig_keys = keys %copy;
@@ -1304,7 +1300,8 @@ sub build_loc {
             mkpath($full_path);
         }
 
-        $loc = "$md5_path/$id$ext";
+
+        $loc = File::Spec->catdir($md5_path,"$id$ext");
     }
 }
 
